# SPRINT: Parallel computing with R on HPC Wales
# 13-May-14
# Exercise 3: papply()

#==============================================================================
#                User defiend function to be applied over data
#==============================================================================

my_stat <- function(x) {
	N <- length(x) # sample size
	r <- floor(N/10) #sub-sample size
	count <- 1000 # number of resamples
	res <- vector(mode = "double", length=N)
	
	for (i in 1:count) {
		y <- x[sample(N,N, replace=TRUE)]
		res[i] <- mean(y)
	}
	return(sd(res))
}

# Combined Test and Training Sets from the Golub Paper
library(golubEsets)
#==============================================================================
#                        Load Data
#==============================================================================

# The data are from Golub et al. These are the combined training samples and
# test samples. There are 47 patients with acute lymphoblastic leukemia (ALL)
# and 25 patients with acute myeloid leukemia (AML). The samples were assayed
# using Affymetrix Hgu6800 chips and data on the expression of 7129 genes
# (Affymetrix probes) are available.

data(Golub_Merge)
golub_data <- exprs(Golub_Merge)

#==============================================================================
#                        SPRINT 
#==============================================================================

stime <- proc.time()["elapsed"]
# We will use papply to filter the correlattion matrix
# stored in a file to save us some disk space.
# Remeber that papply has combined functionality of apply and lapply
# functions, thus it has slightly different interface than sequential
# apply function.

result <- apply(X=golub_data, FUN=my_stat, MARGIN=2)
#result <- papply(data=golub_data, fun=my_stat, margin=2)

etime <- proc.time()["elapsed"]

time <- proc.time()["elapsed"]
print(paste("Apply time: ")); print(paste(etime-stime))

print(paste(result))
# do further analysis of data then exit MPI
# ...

# Shutdown the SPRINT library

quit(save="no")

